clear all
set more off
global drive "C:\Users\JSR343\Dropbox\ABBS_reviseMarch14\paper\Final JMCB\DataCDSsubmission"
use "$drive\MS16-456 DATA.dta", clear

// Define event date
gen event=0
replace event=1 if date>mdy(4,11,2010)
label variable event "Post"

// create interaction variables with event
gen sov_event_perc = event*cds_sov_perc
label var sov_event_perc "Post*Sov CDS"
gen sov_event_Greece_perc = event*Greece_sov_perc
label var sov_event_Greece_perc "Post*Greek Sov CDS"
gen euro=0
replace euro=1 if country==2|country==3|country==9|country==10|country==11|country==12|country==15| ///
	country==17|country==20|country==22|country==26|country==29
label var euro "Euro-country"
gen gipsi=0 if country==7 | country==24| country==25 | country==30 | country==31 | country==33
replace gipsi=1 if country==12 | country==15 | country==17 | country==26 | country==29
label var gipsi "(G)IIPS"


// Figure 1
gen greek_sov_spread=((Greece_ask-Greece_bid))
label var greek_sov_spread "Bid-Ask Spread (bp)"
label var Greece_mid "CDS spread (bp)"
egen day_tag=tag(date)
graph twoway line Greece_mid date if day_tag==1, sort yaxis(2) || ///
			 line greek_sov_spread date if day_tag==1, yaxis(1)  ///
			 sort xlabel(18308(28)18430) xline(18364, lcolor(black) lpattern(solid)) xline(18385, lcolor(gray) lpattern(dash)) ///
			 graphregion(color(white)) legend(color(black) margin(tiny) region( fcolor(white) ///
			 ilcolor(white) margin(tiny) lcolor(white) lpattern(solid)) bmargin(tiny))  ytitle() xline() scheme(sj)
graph export "$drive\figures\greek_spreads.pdf", replace
graph export "$drive\figures\greek_spreads.eps", replace
drop greek_sov_spread day_tag

// Table 1
estpost tabstat cds_corp if event==0, by(country)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table1A1.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace
estpost tabstat cds_corp if event==1, by(country)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table1A2.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace	
egen country_day_tag=tag(country date)
estpost tabstat cds_sov if event==0 & country_day_tag==1, by(country)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table1B1.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace			
estpost tabstat cds_sov if event==1 & country_day_tag==1, by(country)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table1B2.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace
	
// Table 2
estpost tabstat cds_corp if event==0, by(euro)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table2A1.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace
estpost tabstat cds_corp if event==1, by(euro)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table2A2.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace
estpost tabstat cds_corp if event==0, by(gipsi)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table2B1.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace	
estpost tabstat cds_corp if event==1, by(gipsi)  ///
	statistics(mean sd min max count) columns(statistics) 
esttab using "$drive\tables\Table2B2.tex",  ///
			cell("mean(fmt(%9.0f)) sd min max count") fragment	label noobs lines  replace	

// Table 3 Panel A
xi: cluster2 cds_corp_perc cds_sov_perc i.date if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3A.tex", replace keep(cds_sov_perc) ///
	groupvar(cds_sov_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc i.date i.id if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3A.tex", append keep(cds_sov_perc) ///
	groupvar(cds_sov_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc i.date if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3A.tex", append keep(cds_sov_perc) ///
	groupvar(cds_sov_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc i.date i.id if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3A.tex", append keep(cds_sov_perc) ///
	groupvar(cds_sov_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_event_perc cds_sov_perc i.date if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3A.tex", append keep(sov_event_perc cds_sov_perc) ///
	groupvar(sov_event_perc cds_sov_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Difference") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_event_perc cds_sov_perc i.date i.id if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3A.tex", append keep(sov_event_perc cds_sov_perc) ///
	groupvar(sov_event_perc cds_sov_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Difference") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label

// Table 3 Panel B
gen sov_event_perc2 = event*sov_bond_perc
label var sov_event_perc2 "Post*Sov yield"
xi: cluster2 cds_corp_perc sov_bond_perc i.date if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3B.tex", ///
	replace keep(sov_bond_perc) groupvar(sov_bond_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_bond_perc i.date i.id if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3B.tex", ///
	append keep(sov_bond_perc) groupvar(sov_bond_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_bond_perc i.date if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3B.tex", ///
	append keep(sov_bond_perc) groupvar(sov_bond_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_bond_perc i.date i.id if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3B.tex", ///
	append keep(sov_bond_perc) groupvar(sov_bond_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_event_perc2 sov_bond_perc i.date if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3B.tex", ///
	append keep(sov_event_perc2 sov_bond_perc) groupvar(sov_event_perc2 sov_bond_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Difference") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_event_perc2 sov_bond_perc i.date i.id if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table3B.tex", ///
	append keep(sov_event_perc2 sov_bond_perc) groupvar(sov_event_perc2 sov_bond_perc) tex(frag landscape) dec(3) rdec(4) nocons ctitle("Difference") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label

// Table 4
gen CS_sov_event_perc = exposure_greece_above_median*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = exposure_greece_above_median*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = exposure_greece_above_median*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = exposure_greece_above_median
label variable CS "Cross-section (C)"		
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table4.tex", replace tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Non-Financial") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table4.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Non-Financial") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc CS
gen CS_sov_event_perc = exposure_greece_top3*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = exposure_greece_top3*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = exposure_greece_top3*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = exposure_greece_top3
label variable CS "Cross-section (C)"		
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table4.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Non-Financial") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table4.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Non-Financial") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS
gen CS_sov_event_perc = subsidiary_dummy*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = subsidiary_dummy*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = subsidiary_dummy*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = subsidiary_dummy
label variable CS "Cross-section (C)"			
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table4.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Non-Financial") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table4.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Non-Financial") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS

// Table 5 
gen CS_sov_event_perc = pubown*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = pubown*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = pubown*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = pubown
label variable CS "Cross-section (C)"	
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", replace tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Public Ownership") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Public Ownership") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS
** Table 5, columns (3) and (4)
gen CS_sov_event_perc = state_dep*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = state_dep*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = state_dep*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = state_dep
label variable CS "Cross-section (C)"	
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12 & Sector_corp!=4 , fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("State Dependence") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("State Dependence") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS
** Table 5, columns (5) and (6)
gen CS_sov_event_perc = exposure_dom*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = exposure_dom*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = exposure_dom*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = exposure_dom
label variable CS "Cross-section (C)"
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12 & Sector_corp!=4 , fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Sov Exposure") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Sov Exposure") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS
** Table 5, columns (7) and (8)		
gen CS_sov_event_perc = findep*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = findep*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = findep*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = findep
label variable CS "Cross-section (C)"
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12 & Sector_corp!=4 , fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Financial Dependence") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Financial Dependence") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS
** Table 5, columns (9) and (10)		
gen CS_sov_event_perc = bank_based*sov_event_perc
label var CS_sov_event_perc "C*Post*Sov CDS"
gen CS_event = bank_based*event
label variable CS_event "C * Post"
gen CS_cds_sov_perc = bank_based*cds_sov_perc
label variable CS_cds_sov_perc "C * Sov CDS"
gen CS = bank_based
label variable CS "Cross-section (C)"
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS i.date ///
	if country!= 12 & Sector_corp!=4 , fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Bank-based") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc i.date i.id ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table5.tex", append tex(frag landscape) ///
	keep(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	groupvar(CS_sov_event_perc CS_cds_sov_perc CS_event sov_event_perc cds_sov_perc CS) ///
	dec(3) rdec(4) nocons ctitle("Bank-based") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop CS_sov_event_perc CS_event CS_cds_sov_perc	CS
	
// Table 6
xi: cluster2 cds_corp_perc cds_sov_perc cds_corp_spread_change i.date i.id /// use equity volatility instead
	if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", replace tex(frag landscape) ///
	keep(cds_sov_perc cds_corp_spread_change) ///
	groupvar(cds_sov_perc cds_corp_spread_change) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc equity_index_perc i.date i.id ///
	if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc equity_index_perc) ///
	groupvar( cds_sov_perc cds_corp_spread_change equity_index_perc) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc foreign_exposure i.date i.id ///
	if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc foreign_exposure) ///
	groupvar( cds_sov_perc cds_corp_spread_change foreign_exposure) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn i.date i.id ///
	if country!= 12 & event==0, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn) ///
	groupvar( cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn) dec(3) rdec(4) nocons ctitle("Pre-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc cds_corp_spread_change i.date i.id /// use equity volatility instead
	if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc cds_corp_spread_change) ///
	groupvar(cds_sov_perc cds_corp_spread_change) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc equity_index_perc i.date i.id ///
	if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc equity_index_perc) ///
	groupvar(cds_sov_perc cds_corp_spread_change equity_index_perc) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc foreign_exposure i.date i.id ///
	if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc foreign_exposure) ///
	groupvar(cds_sov_perc cds_corp_spread_change foreign_exposure) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn i.date i.id ///
	if country!= 12 & event==1, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn) ///
	groupvar(cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn) dec(3) rdec(4) nocons ctitle("Post-Bailout") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc sov_event_perc cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn i.date i.id ///
	if country!= 12, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table6.tex", append tex(frag landscape) ///
	keep(sov_event_perc cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn) ///
	groupvar(sov_event_perc cds_sov_perc cds_corp_spread_change equity_index_perc foreign_exposure stockreturn) ///
	dec(3) rdec(4) nocons ctitle("Difference") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label


// Table 7
gen nongipsi=0 if country==7 | country==24| country==25 | country==30 | country==31 | country==33
replace nongipsi=1 if country==2 | country==3| country==9| country==10|country==11|country==20|country==22
label var nongipsi "Non-(G)IIPS"
// triple interactions
gen euro_event_cds = euro*sov_event_perc
label var euro_event_cds "Euro*Post*Sov CDS"
gen gipsi_event_cds = gipsi*sov_event_perc
label var gipsi_event_cds "(G)IIPS*Post*Sov CDS"
gen nongipsi_event_cds = nongipsi*sov_event_perc
label var nongipsi_event_cds "Non-(G)IIPS*Post*Sov CDS"
// double interactions
gen euro_event = euro*event
label var euro_event "Euro * Post"
gen euro_sovCDS = euro*cds_sov_perc
label var euro_sovCDS "Euro * Sov CDS"
gen gipsi_event = gipsi*event
label var gipsi_event "(G)IIPS * Post"
gen gipsi_sovCDS = gipsi*cds_sov_perc
label var gipsi_sovCDS "(G)IIPS * Sov CDS"
gen nongipsi_event = nongipsi*event
label var nongipsi_event "Non-(G)IIPS * Post"
gen nongipsi_sovCDS = nongipsi*cds_sov_perc
label var nongipsi_sovCDS "Non-(G)IIPS * Sov CDS"

xi: cluster2 cds_corp_perc euro_event_cds euro_sovCDS euro_event sov_event_perc cds_sov_perc euro i.date ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table7.tex", replace tex(frag landscape) ///
	keep(euro_event_cds euro_sovCDS euro_event sov_event_perc cds_sov_perc euro) ///
	groupvar(euro_event_cds euro_sovCDS euro_event sov_event_perc cds_sov_perc euro) ///
	dec(3) rdec(4) nocons ctitle("Euro") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc euro_event_cds euro_sovCDS euro_event sov_event_perc cds_sov_perc i.id i.date ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table7.tex", append tex(frag landscape) ///
	keep(euro_event_cds euro_sovCDS euro_event sov_event_perc cds_sov_perc) ///
	groupvar(euro_event_cds euro_sovCDS euro_event sov_event_perc cds_sov_perc euro) ///
	dec(3) rdec(4) nocons ctitle("Euro") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc gipsi_event_cds gipsi_sovCDS gipsi_event sov_event_perc cds_sov_perc gipsi i.date ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table7.tex", append tex(frag landscape) ///
	keep(gipsi_event_cds gipsi_sovCDS gipsi_event sov_event_perc cds_sov_perc gipsi) ///
	groupvar(euro_event_cds gipsi_event_cds nongipsi_event_cds euro_sovCDS gipsi_sovCDS nongipsi_sovCDS euro_event gipsi_event nongipsi_event sov_event_perc cds_sov_perc euro gipsi nongipsi) ///
	dec(3) rdec(4) nocons ctitle("(G)IIPS") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc gipsi_event_cds gipsi_sovCDS gipsi_event sov_event_perc cds_sov_perc i.id i.date ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table7.tex", append tex(frag landscape) ///
	keep(gipsi_event_cds gipsi_sovCDS gipsi_event sov_event_perc cds_sov_perc) ///
	groupvar(euro_event_cds gipsi_event_cds nongipsi_event_cds euro_sovCDS gipsi_sovCDS nongipsi_sovCDS euro_event gipsi_event nongipsi_event sov_event_perc cds_sov_perc euro gipsi nongipsi) ///
	dec(3) rdec(4) nocons ctitle("(G)IIPS") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc nongipsi_event_cds nongipsi_sovCDS nongipsi_event sov_event_perc cds_sov_perc nongipsi i.date ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table7.tex", append tex(frag landscape) ///
	keep(nongipsi_event_cds nongipsi_sovCDS nongipsi_event sov_event_perc cds_sov_perc nongipsi) ///
	groupvar(euro_event_cds gipsi_event_cds nongipsi_event_cds euro_sovCDS gipsi_sovCDS nongipsi_sovCDS euro_event gipsi_event nongipsi_event sov_event_perc cds_sov_perc euro gipsi nongipsi) ///
	dec(3) rdec(4) nocons ctitle("Non-(G)IIPS") ///
	addtext(-,-,Time FE, YES, Firm FE, NO,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
xi: cluster2 cds_corp_perc nongipsi_event_cds nongipsi_sovCDS nongipsi_event sov_event_perc cds_sov_perc i.id i.date ///
	if country!= 12 & Sector_corp!=4, fcluster(id) tcluster(date)
outreg2 using "$drive\tables\Table7.tex", append tex(frag landscape) ///
	keep(nongipsi_event_cds nongipsi_sovCDS nongipsi_event sov_event_perc cds_sov_perc) ///
	groupvar(euro_event_cds gipsi_event_cds nongipsi_event_cds euro_sovCDS gipsi_sovCDS nongipsi_sovCDS euro_event gipsi_event nongipsi_event sov_event_perc cds_sov_perc euro gipsi nongipsi) ///
	dec(3) rdec(4) nocons ctitle("Non-(G)IIPS") ///
	addtext(-,-,Time FE, YES, Firm FE, YES,-,-,Cluster Time, YES,Cluster Firm, YES) noni notes label
drop euro_event_cds gipsi_event_cds nongipsi_event_cds euro_event euro_sovCDS gipsi_event gipsi_sovCDS nongipsi_event nongipsi_sovCDS gipsi nongipsi

